=======
Credits
=======

Development Lead
----------------
* `Mark van Koningsveld`_
* `Fedor Baart`_

.. _Mark van Koningsveld: https://www.tudelft.nl/citg/over-faculteit/afdelingen/hydraulic-engineering/sections/rivers-ports-waterways-and-dredging-engineering/staff/van-koningsveld-m/
.. _Fedor Baart: https://www.deltares.nl/en/experts/fedor-baart-3/

Contributors
------------

Various MSc projects

* `Jeroen van der Does de Willebois`_, 2019. **Assessing the impact of quay-wall renovations on the nautical traffic in Amsterdam: A simulation study.** MSc thesis. Delft University of Technology, Civil Engineering and Geosciences, Hydraulic Engineering - Ports and Waterways. Delft, the Netherlands.
* `Leonore Vehmeijer`_, 2019. **Measures for the reduction of CO2 emissions, by the inland shipping fleet, on the Rotterdam-Antwerp corridor.** MSc thesis. Delft University of Technology, Civil Engineering and Geosciences, Hydraulic Engineering - Ports and Waterways. Delft, the Netherlands.
* `Sophie Ensing`_, 2019. **Agent-based modeling and simulation of public transport to identify effects of network changes on passenger flows.** MSc thesis. University of Amsterdam, Faculty of Science, Data Science, Information Studies. Amsterdam, the Netherlands.
* `Loes Segers`_, 2021. **Mapping inland shipping emissions in time and space for the benefit of emission policy development: A case study on the Rotterdam-Antwerp corridor.** MSc thesis. Delft University of Technology, Civil Engineering and Geosciences, Hydraulic Engineering - Ports and Waterways. Delft, the Netherlands.

.. _Jeroen van der Does de Willebois: http://resolver.tudelft.nl/uuid:22eddd89-21a2-4819-ba1f-ee905a829364
.. _Leonore Vehmeijer: http://resolver.tudelft.nl/uuid:1abd88e0-9ab6-47fd-a503-2f19ba13bbff
.. _Sophie Ensing: http://scriptiesonline.uba.uva.nl/scriptie/690471
.. _Loes Segers: http://resolver.tudelft.nl/uuid:a260bc48-c6ce-4f7c-b14a-e681d2e528e3